# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway_staking_mode.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1agateway_staking_mode.proto\x12\x06helium*9\n\x14gateway_staking_mode\x12\x0c\n\x08\x64\x61taonly\x10\x00\x12\x08\n\x04\x66ull\x10\x01\x12\t\n\x05light\x10\x02\x62\x06proto3')

_GATEWAY_STAKING_MODE = DESCRIPTOR.enum_types_by_name['gateway_staking_mode']
gateway_staking_mode = enum_type_wrapper.EnumTypeWrapper(_GATEWAY_STAKING_MODE)
dataonly = 0
full = 1
light = 2


if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GATEWAY_STAKING_MODE._serialized_start=38
  _GATEWAY_STAKING_MODE._serialized_end=95
# @@protoc_insertion_point(module_scope)
